-- /////////////////////////////////////////////////////////////////////////////
-- =============================================================================
--  CLEARFONT2 BY KIRKBURN
--  Official website:  http://www.clearfont.co.uk/
-- -----------------------------------------------------------------------------
--  CORE.LUA - STANDARD WOW UI FONTS
--	A. FONT LOCALS
--	B. SETTING UP THE ADDON
--	C. APPLY THE FONT CHOICES
-- =============================================================================
-- /////////////////////////////////////////////////////////////////////////////



-- -----------------------------------------------------------------------------
-- Create instance of the Ace2 addon
-- -----------------------------------------------------------------------------

ClearFont = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceConsole-2.0", "AceDB-2.0", "FuBarPlugin-2.0")



-- =============================================================================
--  A. FONT LOCALS
-- =============================================================================

local fontLoc = "Interface\\AddOns\\ClearFont2\\Fonts\\"
ClearFont.fonts = 
{
	{["name"]="Default (Calibri v1)",	
		["normal"]		=fontLoc.."Calibri_v1\\Calibri.ttf",
		["bold"]		=fontLoc.."Calibri_v1\\CalibriBold.ttf",
		["italic"]		=fontLoc.."Calibri_v1\\CalibriItalic.ttf",
		["bolditalic"]	=fontLoc.."Calibri_v1\\CalibriBoldItalic.ttf", 
		["number"]		=fontLoc.."Calibri_v1\\CalibriBold.ttf"},

	{["name"]="Baar Philos",
		["normal"]		=fontLoc.."BaarPhilos\\BaarPhilos.ttf",
		["bold"]		=fontLoc.."BaarPhilos\\BaarPhilosBold.ttf", 
		["italic"]		=fontLoc.."BaarPhilos\\BaarPhilosItalic.ttf", 
		["bolditalic"]	=fontLoc.."BaarPhilos\\BaarPhilosBoldItalic.ttf",
		["number"]		=fontLoc.."BaarPhilos\\BaarPhilosBold.ttf"},

	{["name"]="Baar Sophia",
		["normal"]		=fontLoc.."BaarSophia\\BaarSophia.ttf",
		["bold"]		=fontLoc.."BaarSophia\\BaarSophiaBold.ttf",
		["italic"]		=fontLoc.."BaarSophia\\BaarSophiaItalic.ttf",
		["bolditalic"]	=fontLoc.."BaarSophia\\BaarSophiaBoldItalic.ttf",
		["number"]		=fontLoc.."BaarSophia\\BaarSophiaBold.ttf"},

	{["name"]="Calibri v0.9",
		["normal"]		=fontLoc.."Calibri_v0.9\\Calibri.ttf",
		["bold"]		=fontLoc.."Calibri_v0.9\\CalibriBold.ttf", 
		["italic"]		=fontLoc.."Calibri_v0.9\\CalibriItalic.ttf",
		["bolditalic"]	=fontLoc.."Calibri_v0.9\\CalibriBoldItalic.ttf",
		["number"]		=fontLoc.."Calibri_v0.9\\CalibriBold.ttf"},

	{["name"]="Francophil Sans",
		["normal"]		=fontLoc.."Franc\\Franc.ttf",
		["bold"]		=fontLoc.."Franc\\FrancBold.ttf",
		["italic"]		=fontLoc.."Franc\\Franc.ttf",
		["bolditalic"]	=fontLoc.."Franc\\FrancBold.ttf",
		["number"]		=fontLoc.."Franc\\FrancBold.ttf"},

	{["name"]="Lucida Grande",
		["normal"]		=fontLoc.."LucidaGrande\\LucidaGrande.ttf",
		["bold"]		=fontLoc.."LucidaGrande\\LucidaGrande.ttf",
		["italic"]		=fontLoc.."LucidaGrande\\LucidaGrande.ttf",
		["bolditalic"]	=fontLoc.."LucidaGrande\\LucidaGrande.ttf",
		["number"]		=fontLoc.."LucidaGrande\\LucidaGrande.ttf"},

	{["name"]="Lucida Sans Demibold",
		["normal"]		=fontLoc.."LucidaSD\\LucidaSD.ttf",
		["bold"]		=fontLoc.."LucidaSD\\LucidaSD.ttf",
		["italic"]		=fontLoc.."LucidaSD\\LucidaSDItalic.ttf",
		["bolditalic"]	=fontLoc.."LucidaSD\\LucidaSDItalic.ttf",
		["number"]		=fontLoc.."LucidaSD\\LucidaSD.ttf"},

	{["name"]="Perspective Sans",
		["normal"]		=fontLoc.."PerspectiveSans\\PerspectiveSans.ttf",
		["bold"]		=fontLoc.."PerspectiveSans\\PerspectiveSansBold.ttf",
		["italic"]		=fontLoc.."PerspectiveSans\\PerspectiveSansItalic.ttf",
		["bolditalic"]	=fontLoc.."PerspectiveSans\\PerspectiveSansBoldItalic.ttf",
		["number"]		=fontLoc.."PerspectiveSans\\PerspectiveSansBold.ttf"},

	{["name"]="Tin Birdhouse",
		["normal"]		=fontLoc.."TinBirdhouse\\TinBirdhouse.ttf",
		["bold"]		=fontLoc.."TinBirdhouse\\TinBirdhouse.ttf",
		["italic"]		=fontLoc.."TinBirdhouse\\TinBirdhouse.ttf",
		["bolditalic"]	=fontLoc.."TinBirdhouse\\TinBirdhouse.ttf",
		["number"]		=fontLoc.."TinBirdhouse\\TinBirdhouse.ttf"},
}



-- =============================================================================
--  B. SETTING UP THE ADDON
-- =============================================================================

-- -----------------------------------------------------------------------------
-- Localization
-- -----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("ClearFont")

L:RegisterTranslations("enUS", function() return {

	["Font face"] = true,
	["Changes the font face for the user interface. Some changes may require a UI reload (/rl)."] = true,
	["Font size"] = true,
	["Changes the font size for the user interface by a percentage."] = true,

	["Right-Click for options."] = true,

    ["Apply to addons"] = true,
	["Applies the font settings to all addons"] = true,
} end)


-- -----------------------------------------------------------------------------
-- Set defaults
-- -----------------------------------------------------------------------------

local defaults = {
	currentFont = "Default (Calibri v1)",
	currentScale = 1.0,
	applyAll = true,
}


-- -----------------------------------------------------------------------------
-- Dewdrop Menu
-- -----------------------------------------------------------------------------

local menu = {
	type = "group",
	args = {
		font = {
			type = "text",
			name = L["Font face"],
			desc = L["Changes the font face for the user interface. Some changes may require a UI reload (/rl)."],
			get  = function() return ClearFont.db.profile.currentFont end,
			set  = function(v)
				ClearFont.db.profile.currentFont = v
				ClearFont:ApplyFont()
				end,
			order = 1,
		},
		scale = {
			type = "range",
			name = L["Font size"],
			desc = L["Changes the font size for the user interface by a percentage."],
			get = function() return ClearFont.db.profile.currentScale end,
			set = function(v)
				ClearFont.db.profile.currentScale = v
				ClearFont:ApplyFont()
				end,
			min = 0.6,
			max = 1.4,
			step = 0.02,
			isPercent = true,
            order = 2,
		},
		applyaddons = {
			name = L["Apply to addons"],
			type = 'toggle',
			desc = L["Applies the font settings to all addons"],
			get = function()
				return ClearFont.db.profile.applyAll
			end,
			set = function(option)
				ClearFont.db.profile.applyAll = option
				ClearFont:ApplyFont()
			end,
			order = 3,
		},        
	}
}


-- -----------------------------------------------------------------------------
-- FuBar 2.0 Options
-- -----------------------------------------------------------------------------

ClearFont.OnMenuRequest = menu
ClearFont.hasIcon = true
ClearFont.defaultMinimapPosition = 200
ClearFont.cannotDetachTooltip = true
ClearFont.independentProfile = true
ClearFont.defaultPosition = "LEFT"
ClearFont.hideWithoutStandby = true
ClearFont.hasNoColor = true

local tablet = AceLibrary("Tablet-2.0")
function ClearFont:OnTooltipUpdate()
	tablet:SetHint(L["Right-Click for options."])
end


-- -----------------------------------------------------------------------------
-- Startup call when addon is loaded
-- -----------------------------------------------------------------------------

function ClearFont:OnInitialize()
	self:RegisterDB("ClearFontDB")
	self:RegisterDefaults("profile", defaults )
	menu.args.font.validate = self:GetFonts()
	self:RegisterChatCommand( {"/ClearFont", "/CF", "/ClearFont2", "/CF2"}, menu )
	self:RegisterEvent("ADDON_LOADED", "ApplyFont")
end


-- -----------------------------------------------------------------------------
-- Get the font choices
-- -----------------------------------------------------------------------------

function ClearFont:GetFonts()
	local fontNames = {}
	for i in pairs(ClearFont.fonts) do
		table.insert(fontNames,ClearFont.fonts[i].name)
	end
	table.sort(fontNames)
	return fontNames
end


-- ----------------------------------------------------------------------------
-- Called by addon packs once they've added fonts
-- ----------------------------------------------------------------------------

function ClearFont:UpdateFontList()
	menu.args.font.validate = self:GetFonts()
end

-- =============================================================================
--  C. APPLY THE FONT CHOICES
-- =============================================================================

function ClearFont:ApplyFont()
	index = 1
	for i in pairs(ClearFont.fonts) do
		if ClearFont.fonts[i].name == ClearFont.db.profile.currentFont then
			index = i
		end
	end
	if not ClearFont.fonts[index].normal then return end

	if type(ApplyClearFontDesign) == "function" then
		ApplyClearFontDesign()
	end

	if type(ApplyCustomClearFontDesign) == "function" then
		ApplyCustomClearFontDesign()
	end
end

